@@ -8,7 +8,8 @@ from typing import Optional, cast
 import click
 
 from konigle import models
-from konigle.cli.main import cli, get_client
+from konigle.cli.comm.base import comm
+from konigle.cli.main import get_client
 from konigle.filters.comm import (
     EmailChannelFilters,
     EmailIdentityFilters,
@@ -52,12 +53,6 @@ def print_verification_help(identity_id, record_type="verification"):
     click.echo(f"   konigle comm email identities check-status {identity_id}")
 
 
-@cli.group()
-def comm() -> None:
-    """Communication management commands."""
-    pass
-
-
 @comm.group()
 def email() -> None:
     """Email communication commands."""
@@ -719,6 +714,13 @@ def setup_custom_mail_from(
     is_flag=True,
     help="Save email as template for future use",
 )
+@click.option(
+    "--header",
+    "headers",
+    multiple=True,
+    help="Custom headers in Key:Value format (can be used multiple times). "
+    "Keys must start with 'X-'",
+)
 @click.pass_context
 def send_email(
     ctx: click.Context,
@@ -732,6 +734,7 @@ def send_email(
     category: Optional[str],
     attachments: tuple,
     save_as_template: bool,
+    headers: tuple,
 ) -> None:
     """Send an email through the Konigle email service."""
     try:
@@ -742,6 +745,29 @@ def send_email(
             click.echo("✗ Error: Maximum 10 attachments allowed", err=True)
             ctx.exit(1)
 
+        # Parse custom headers
+        parsed_headers = None
+        if headers:
+            parsed_headers = {}
+            for header in headers:
+                if ":" not in header:
+                    click.echo(
+                        f"✗ Error: Invalid header format '{header}'. "
+                        "Use 'Key:Value' format",
+                        err=True,
+                    )
+                    ctx.exit(1)
+                key, value = header.split(":", 1)
+                key = key.strip()
+                value = value.strip()
+                if not key.startswith("X-"):
+                    click.echo(
+                        f"✗ Error: Header key '{key}' must start with 'X-'",
+                        err=True,
+                    )
+                    ctx.exit(1)
+                parsed_headers[key] = value
+
         # Process attachments - validate file paths exist
         processed_attachments = []
         for path in attachments:
@@ -780,6 +806,7 @@ def send_email(
                 processed_attachments if processed_attachments else None
             ),
             save_as_template=save_as_template,
+            headers=parsed_headers,
         )
 
         result = client.emails.send(email_data)
@@ -818,6 +845,11 @@ def templates() -> None:
     multiple=True,
     help="Tags for categorizing template (can be used multiple times)",
 )
+@click.option(
+    "--is-base",
+    is_flag=True,
+    help="Mark this template as a base template for the account",
+)
 @click.pass_context
 def create_template(
     ctx: click.Context,
@@ -827,6 +859,7 @@ def create_template(
     body_html: str,
     body_text: Optional[str],
     tags: tuple,
+    is_base: bool,
 ) -> None:
     """Create a new email template."""
     try:
@@ -839,6 +872,7 @@ def create_template(
             body_html=body_html,
             body_text=body_text or "",
             tags=list(tags) if tags else [],
+            is_base=is_base,
         )
 
         result = client.email_templates.create(template_data)
@@ -858,6 +892,12 @@ def create_template(
 )
 @click.option("--search", "-q", help="Search in name, code, and tags")
 @click.option("--tags", help="Filter by tags (comma-separated)")
+@click.option(
+    "--is-base",
+    type=click.BOOL,
+    default=None,
+    help="Filter by base template status (true/false)",
+)
 @click.option(
     "--ordering",
     help="Order by field (name, code, created_at, updated_at). "
@@ -870,6 +910,7 @@ def list_templates(
     page_size: int,
     search: Optional[str],
     tags: Optional[str],
+    is_base: Optional[bool],
     ordering: Optional[str],
 ) -> None:
     """List email templates."""
@@ -879,6 +920,7 @@ def list_templates(
         filters = EmailTemplateFilters(
             q=search,
             tags=tags,
+            is_base=is_base,
             ordering=ordering,  # type: ignore
         )
 
@@ -931,6 +973,11 @@ def get_template(ctx: click.Context, template_id: str) -> None:
     multiple=True,
     help="Replace tags with new ones (can be used multiple times)",
 )
+@click.option(
+    "--is-base/--no-is-base",
+    default=None,
+    help="Mark or unmark this template as a base template",
+)
 @click.pass_context
 def update_template(
     ctx: click.Context,
@@ -941,6 +988,7 @@ def update_template(
     body_html: Optional[str],
     body_text: Optional[str],
     tags: tuple,
+    is_base: Optional[bool],
 ) -> None:
     """Update an email template."""
     try:
@@ -959,6 +1007,8 @@ def update_template(
             update_data["body_text"] = body_text
         if tags:
             update_data["tags"] = list(tags)
+        if is_base is not None:
+            update_data["is_base"] = is_base
 
         if not update_data:
             click.echo("No update fields provided.", err=True)
