@@ -9,6 +9,7 @@ from konigle.models.commerce.base import TimestampedResource
 from konigle.models.commerce.product import (
     Product,
     ProductCreate,
+    ProductOption,
     ProductStatus,
     ProductUpdate,
 )
@@ -31,6 +32,7 @@ __all__ = [
     "ProductCreate",
     "ProductUpdate",
     "ProductStatus",
+    "ProductOption",
     # Product Image models
     "ProductImage",
     "ProductImageCreate",
