@@ -6,6 +6,7 @@ including common timestamp patterns and shared field definitions.
 """
 
 from datetime import datetime
+from typing import Optional
 
 from pydantic import BaseModel, Field
 
@@ -36,15 +37,15 @@ class TimestampedResource(BaseModel):
     across products, variants, and images.
     """
 
-    djshopify_created: datetime = Field(
-        ...,
+    created_at: Optional[datetime] = Field(
+        default=None,
         title="Created At",
         description="Timestamp when the resource was created.",
     )
     """Created timestamp of the resource."""
 
-    djshopify_updated: datetime = Field(
-        ...,
+    updated_at: Optional[datetime] = Field(
+        default=None,
         title="Updated At",
         description="Timestamp when the resource was last updated in the source system.",
     )
